function openIndexedDB (fileindex) {
  // This works on all devices/browsers, and uses IndexedDBShim as a final fallback 
  var indexedDB = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB || window.shimIndexedDB;

  var openDB = indexedDB.open("Personalized", 1);

  openDB.onupgradeneeded = function() {
    var db = {}
    db.result = openDB.result;
    db.store = db.result.createObjectStore("PersonalizedStore", {keyPath: "id"});
    if (fileindex) db.index = db.store.createIndex("PersonalizedIndex", fileindex);
  };

  return openDB;
}

function getStoreIndexedDB (openDB) {
  var db = {};
  db.result = openDB.result;
  db.tx = db.result.transaction("PersonalizedStore", "readwrite");
  db.store = db.tx.objectStore("PersonalizedStore");
  try {
      db.index = db.store.index("PersonalizedIndex");
  } catch (ex){}

  return db;
}

function saveIndexedDB (filename, filedata, fileindex) {
  var openDB = openIndexedDB(fileindex);

  openDB.onsuccess = function() {
    var db = getStoreIndexedDB(openDB);

    db.store.put({id: filename, data: filedata});
  }

  return true;
}

function deleteObjectIndexedDB (filename, fileindex) {
  var openDB = openIndexedDB(fileindex);

  openDB.onsuccess = function() {
    var db = getStoreIndexedDB(openDB);
    var request = db.store.delete(filename);
    request.onsuccess = function() {
      console.log(request, 'request');
    };
  }

  return true;
}

function findIndexedDB (filesearch, callback) {
  return loadIndexedDB(null, callback, filesearch);
}

function loadIndexedDB (filename, callback, filesearch) {
  var openDB = openIndexedDB();

  openDB.onsuccess = function() {
    var db = getStoreIndexedDB(openDB);

    var getData = null;
    if (filename) {
      getData = db.store.get(filename);
    } else {
      getData = db.index.get(filesearch);
    }
    
    getData.onsuccess = function() {
        if (typeof(getData.result) != "undefined") {
          callback(getData.result.data);  
        }
      
    };

    db.tx.oncomplete = function() {
      db.result.close();
    };
  }

  return true;
}