<?php
/**
 * Plugin Name:       Dastomize - Advanced Interactive Product Designer & Personalizer for WooCommerce
 * Description:       A Reliable and Fast Interactive Product Designer & Personalizer For E-Commerce & Print-On-Demand Businesses At Scale. Dastomize developed All-In-One Personalization & Growth Acceleration Management Platform (PGAM) for WooCommerce / Shopify and other popular e-Commerce platforms.
 * Plugin URI:        https://www.dastomize.com
 * Version:           0.0.73
 * Author:            Dasble Technologies Inc.
 * Author URI:        https://www.dasble.com
 * WC tested up to:   6.0.1
 * WC requires at least: 5.0
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

require_once(plugin_dir_path(__FILE__) . 'vendor/autoload.php');

define( 'DASTOMIZE_PATH', realpath( dirname(__FILE__) ) );
$dotenv = Dotenv\Dotenv::createUnsafeImmutable(DASTOMIZE_PATH);
$dotenv->safeLoad();

define( 'DASTOMIZE__FILE__', __FILE__ );
define( 'DASTOMIZE_PLUGIN_BASE', plugin_basename( DASTOMIZE__FILE__ ) );

define( 'DASTOMIZE_LICENSE', true );
define( 'DASTOMIZE_URL', plugins_url() . '/' . basename(dirname(__FILE__)) . '/' );
define( 'DASTOMIZE_INCLUDES', DASTOMIZE_PATH . '/includes/');
define( 'DASTOMIZE_COMMON', DASTOMIZE_PATH . '/common/');
define( 'DASTOMIZE_HTML', DASTOMIZE_PATH . '/html/');

include (DASTOMIZE_COMMON . 'helper.php');

define( 'DASTOMIZE_APP_URL', dastomize_env('DAST_APP_URL', 'https://app.dastomize.com'));
define( 'DASTOMIZE_IFRAME_URL', dastomize_env('DAST_IFRAME_URL', 'https://iframe.dastomize.com'));
define( 'DASTOMIZE_GCLOUD_STORAGE_KEY_FILE', '');
define( 'DASTOMIZE_APP_API_GET_STORES', '/api/v1/stores?platform=woo');
define( 'DASTOMIZE_APP_API_PERSONALIZED_BY_UUID', '/api/v1/stores/%s/product/%s/getUUID/%s');
define( 'DASTOMIZE_APP_API_PRODUCT_CUSTOM_ATTRIBUTE', '/api/v1/stores/%s/product-custom-attributes/%s/validate');
define( 'DASTOMIZE_APP_API_PRODUCT_SETTINGS', '/api/v1/stores/%s/settings-display/%s');
define( 'DASTOMIZE_APP_API_PERSONALIZED_GENERATE_FINALDESIGN', '/api/v1/stores/%s/product/%s/generate-final-design');
define( 'DASTOMIZE_APP_CONNECT_STORE', '/stores/woo/connect?domain=%s&title=%s');
define( 'DASTOMIZE_APP_API_S3_GET_UPLOAD', DASTOMIZE_APP_URL . '/api/v1/s3/upload');
define( 'DASTOMIZE_APP_REGISTER', DASTOMIZE_APP_URL . '/register');

include (DASTOMIZE_INCLUDES . 'functions.php');
include (DASTOMIZE_INCLUDES . 'webhook-functions.php');
include (DASTOMIZE_INCLUDES . 'custom-api.php');
include (DASTOMIZE_INCLUDES . 'admin/notices.php');

add_action('admin_menu', 'dastomize_Menu');
function dastomize_Menu(){
    $appNameLower = strtolower(dastomize_env('DAST_APP_NAME', 'dastomize'));
    $icon_data_uri = DASTOMIZE_URL . 'assets/images/' . $appNameLower . '-menu-icon.svg';

	add_menu_page (
        dastomize_env('DAST_PAGE_TITLE', 'Dastomize'),
        dastomize_env('DAST_MENU_TITLE', 'Dastomize'),
        'manage_options',
        'dastomize-apps-menu',
        'dastomize_general_settings',
        $icon_data_uri,
        '100'
    );
}

function dastomize_general_settings(){
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }
    include('html/tab-pane-settings.html.php');
}

add_filter( 'plugin_row_meta', 'dastomize_plugin_row_meta', 10, 2 );
function dastomize_plugin_row_meta( $plugin_meta, $plugin_file ) {
    if ( DASTOMIZE_PLUGIN_BASE === $plugin_file ) {
        $row_meta = [
            'help' => '<a href="https://support.dastomize.com" aria-label="' . esc_attr( __( 'Help Center', 'dastomize' ) ) . '" target="_blank">' . __( 'Help Center', 'dastomize' ) . '</a>',
            'video' => '<a href="https://www.youtube.com/channel/UCa6nkS9YJkfVWqhnaSx_Img" aria-label="' . esc_attr( __( 'Video Tutorials', 'dastomize' ) ) . '" target="_blank">' . __( 'Video Tutorials', 'dastomize' ) . '</a>',
            'site' => '<a href="https://www.dastomize.com" aria-label="' . esc_attr( __( 'Visit Plugin site', 'dastomize' ) ) . '" target="_blank">' . __( 'Visit Plugin site', 'dastomize' ) . '</a>',
        ];

        $plugin_meta = array_merge( $plugin_meta, $row_meta );
    }

    return $plugin_meta;
}

add_filter( 'plugin_action_links_' . DASTOMIZE_PLUGIN_BASE, 'dastomize_plugin_action_links' );
function dastomize_plugin_action_links( $links ) {
    $settings_link = sprintf( '<a href="%1$s">%2$s</a>', admin_url( 'admin.php?page=dastomize-apps-menu' ), __( 'Settings', 'dastomize' ) );

    array_unshift( $links, $settings_link );

    return $links;
}