<?php

class DASTOMIZE_Custom_Controller {
    protected $namespace = 'wc/v3';
    protected $rest_metadata = 'dastomize_metadata';
    protected $rest_upload_media = 'dastomize_upload_media';

    public function get_metadata($request) {
        $res =  ['store_id' => get_option('settings_page_app_store'), 'token' => get_option('settings_page_api_token')];

        $response = new WP_REST_Response($res);
        $response->set_status(200);

        return $response;
    }

    public function update_metadata($request) {
        if (!(isset($request['store_id']) && isset($request['token']))) {
            $res = ['message' => 'Permission Denied'];
            $response = new WP_REST_Response($res);
            $response->set_status(400);
            return $response;
        }

        $data['store_id'] = (int) sanitize_text_field($request['store_id']);
        $data['token'] = sanitize_text_field($request['token']);

        update_option('settings_page_app_store', $data['store_id']);
        update_option('settings_page_api_token', $data['token']);
        update_option('dastomize_activated', 'yes');

        $response = new WP_REST_Response('');
        $response->set_status(204);

        return $response;
    }

    public function delete_metadata($request) {
        if (!(isset($request['store_id']))) {
            $res = ['message' => 'Permission Denied'];
            $response = new WP_REST_Response($res);
            $response->set_status(400);
            return $response;
        }

        delete_option('settings_page_app_store');
        delete_option('settings_page_api_token');
        delete_option('dastomize_activated');

        $response = new WP_REST_Response('');
        $response->set_status(204);

        return $response;
    }

    public function upload_file($request) {
        if(! isset( $request['image_url'] ) ) {
            $response = new WP_REST_Response(['error' => 'No image url selected.']);
            $response->set_status(400);

            return $response;
        }

        if ( ! function_exists( 'download_url' ) ) {
            require_once( ABSPATH . 'wp-admin/includes/file.php' );
        }
        $image_url = $request['image_url'];
        $temp_file = download_url( $image_url );

        if( is_wp_error( $temp_file ) ) {
            $response = new WP_REST_Response(['error' => 'No image url.']);
            $response->set_status(400);

            return $response;
        }

        // move the temp file into the uploads directory
        $file = array(
            'name'     => basename( $image_url ),
            'type'     => mime_content_type( $temp_file ),
            'tmp_name' => $temp_file,
            'size'     => filesize( $temp_file ),
        );
        $sideload = wp_handle_sideload(
            $file,
            array(
                'test_form'   => false // no needs to check 'action' parameter
            )
        );

        if( ! empty( $sideload[ 'error' ] ) ) {
            // you may return error message if you want
            $response = new WP_REST_Response(['error' => $sideload[ 'error' ]]);
            $response->set_status(400);

            return $response;
        }

        $attachment_id = wp_insert_attachment(
            array(
                'guid'           => $sideload[ 'url' ],
                'post_mime_type' => $sideload[ 'type' ],
                'post_title'     => basename( $sideload[ 'file' ] ),
                'post_content'   => '',
                'post_status'    => 'inherit',
            ),
            $sideload[ 'file' ]
        );
    
        if( is_wp_error( $attachment_id ) || ! $attachment_id ) {
            $response = new WP_REST_Response(['error' => 'Upload error.']);
            $response->set_status(400);

            return $response;
        }

        // update medatata, regenerate image sizes
        require_once( ABSPATH . 'wp-admin/includes/image.php' );

        wp_update_attachment_metadata(
            $attachment_id,
            wp_generate_attachment_metadata( $attachment_id, $sideload[ 'file' ] )
        );


        $response = new WP_REST_Response(['source_url' => $sideload[ 'url' ], 'id' => $attachment_id]);
        $response->set_status(200);

        return $response;
    }

    public function register_routes() {
        register_rest_route($this->namespace, '/' . $this->rest_metadata, [
            'methods' => 'GET',
            'callback' => [$this, 'get_metadata'],
            'permission_callback' => '__return_true'
        ]);

        register_rest_route($this->namespace, '/' . $this->rest_metadata, [
            'methods' => 'PUT',
            'callback' => [$this, 'update_metadata'],
            'permission_callback' => '__return_true'
        ]);

        register_rest_route($this->namespace, '/' . $this->rest_metadata, [
            'methods' => 'DELETE',
            'callback' => [$this, 'delete_metadata'],
            'permission_callback' => '__return_true'
        ]);

        register_rest_route($this->namespace, '/' . $this->rest_upload_media, [
            'methods' => 'POST',
            'callback' => [$this, 'upload_file'],
            'permission_callback' => '__return_true'
        ]);
    }
}
add_filter('woocommerce_rest_api_get_rest_namespaces', 'dastomize_woo_metadata_api');

function dastomize_woo_metadata_api($controllers) {
    $controllers['wc/v3']['metadata'] = 'DASTOMIZE_Custom_Controller';

    return $controllers;
}
