<?php

use Google\Cloud\Core\Exception\GoogleException;
use Google\Cloud\Storage\StorageClient;

if ( !function_exists('dastomize_upload_image_preview')) {
    function dastomize_upload_image_preview($storeId, $productId, $imgBase64)
    {
        try {
            $folder = 'preview/';
            $newName = dastomize_generate_random_string(20);

            $destinationFinalPath = dastomize_destination_path($folder . $storeId . '/' . $productId);

            $namePreview = $destinationFinalPath . $newName . '.preview-' . time() . '.jpg';

            $imageSrc = substr($imgBase64, strpos($imgBase64, ',') + 1);
            $imageSrc = base64_decode($imageSrc);

            $storage = new StorageClient([
                'keyFilePath' => DASTOMIZE_GCLOUD_STORAGE_KEY_FILE
            ]);
            
            $bucketName = dastomize_env('GCS_BUCKET_NAME', 'cdn.cubebik.com');

            $env = dastomize_env('DAST_APP_ENV', 'prod');
            if ($env == 'dev') {
                $namePreview = 'dev/' . $namePreview;
            }
            $bucket = $storage->bucket($bucketName);
            $bucket->upload($imageSrc, [
                'resumable' => true,
                'name' => $namePreview,
                'predefinedAcl' => 'publicRead'
            ]);
            return dastomize_get_original_url() . $namePreview;
        } catch (GoogleException $ex) {
            dastomize_write_log_error('[dastomize_upload_image_preview] Error: ' . $ex->getMessage());
            return null;
        }
    }
}


if ( !function_exists('dastomize_remove_image_preview')) {
    function dastomize_remove_image_preview($previewUrl)
    {
        try {
            $storage = new StorageClient([
                'keyFilePath' => DASTOMIZE_GCLOUD_STORAGE_KEY_FILE
            ]);
            $bucketName = dastomize_env('GCS_BUCKET_NAME', 'cdn.cubebik.com');
            $objectName = str_replace(dastomize_get_original_url(), '', $previewUrl);
            $bucket = $storage->bucket($bucketName);
            $object = $bucket->object($objectName);
            $object->delete();
            return $objectName;
        } catch (GoogleException $ex) {
            dastomize_write_log_error('[dastomize_remove_image_preview] Error: ' . $ex->getMessage());
            return null;
        }
    }
}

if ( !function_exists('dastomize_upload_json')) {
    function dastomize_upload_json($storeId, $productId, $json)
    {
        try {
            $folder = 'final-design/json/';
            $newName = dastomize_generate_random_string(20);

            $destinationFinalPath = dastomize_destination_path($folder . $storeId . '/' . $productId);

            $nameJson = $destinationFinalPath . $newName . '.json-' . time() . '.json';

            $storage = new StorageClient([
                'keyFilePath' => DASTOMIZE_GCLOUD_STORAGE_KEY_FILE
            ]);
            
            $bucketName = dastomize_env('GCS_BUCKET_NAME', 'cdn.cubebik.com');

            $env = dastomize_env('DAST_APP_ENV', 'prod');
            if ($env == 'dev') {
                $nameJson = 'dev/' . $nameJson;
            }
            $bucket = $storage->bucket($bucketName);
            $bucket->upload($json, [
                'resumable' => true,
                'name' => $nameJson,
                'predefinedAcl' => 'publicRead'
            ]);
            return str_replace('dev/', '', $nameJson);
        } catch (GoogleException $ex) {
            dastomize_write_log_error('[dastomize_upload_json] Error: ' . $ex->getMessage());
            return null;
        }
    }
}

if ( !function_exists('dastomize_remove_json')) {
    function dastomize_remove_json($jsonUrl)
    {
        try {
            $storage = new StorageClient([
                'keyFilePath' => DASTOMIZE_GCLOUD_STORAGE_KEY_FILE
            ]);
            $bucketName = dastomize_env('GCS_BUCKET_NAME', 'cdn.cubebik.com');
            $objectName = str_replace(dastomize_get_original_url(), '', $jsonUrl);
            $bucket = $storage->bucket($bucketName);
            $object = $bucket->object($objectName);
            $object->delete();
            return $objectName;
        } catch (GoogleException $ex) {
            dastomize_write_log_error('[dastomize_remove_json] Error: ' . $ex->getMessage());
            return null;
        }
    }
}

if (! function_exists('dastomize_destination_path')) {
    function dastomize_destination_path($root = 'uploads/')
    {
        $dt = \Carbon\Carbon::now();
        $dest = "$root/{$dt->format('m/Y')}/";
        return $dest;
    }
}

if (! function_exists('dastomize_generate_random_string')) {
    function dastomize_generate_random_string($length = 10) {
        return substr(str_shuffle(str_repeat($x='0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ', ceil($length/strlen($x)) )),1,$length);
    }
}

if (! function_exists('dastomize_get_original_url')) {
    function dastomize_get_original_url() {
        return dastomize_env('GCS_ORIGINAL_URL', 'https://cdn.cubebik.com/');
    }
}
