<?php

use GuzzleHttp\Client;

if ( !function_exists('dastomize_s3_upload_image_preview')) {
    function dastomize_s3_upload_image_preview($storeId, $productId, $imgBase64)
    {
        try {
            $folder = 'preview/';
            $newName = dastomize_s3_generate_random_string(20);

            $destinationFinalPath = dastomize_s3_destination_path($folder . $storeId . '/' . $productId);

            $fileName = $newName . '.preview-' . time() . '.jpg';

            $imageSrc = substr($imgBase64, strpos($imgBase64, ',') + 1);
            $imageSrc = base64_decode($imageSrc);

            $apiToken = get_option('settings_page_api_token');
            $remoteUrl = DASTOMIZE_APP_API_S3_GET_UPLOAD;

            $client = new Client([
                'timeout'         => 300,
            ]);
            $res = $client->request('GET', $remoteUrl, [
                'headers' => [
                    'Authorization' => 'Bearer ' . $apiToken,
                    'x-amz-meta-filename'   => $fileName,
                    'x-amz-meta-filepath'   => $destinationFinalPath
                ]
            ]);
            $body = json_decode($res->getBody()->getContents());
            if (!empty($body->signed)) {
                $signedUrl = $body->signed;
                $url = $body->url;

                $res = $client->request('PUT', $signedUrl, [
                    'headers' => [
                        'Content-Type' => 'image/jpeg',
                    ],
                    'body' => $imageSrc
                ]);
                return $url;
            }
            
        } catch (\Exception $ex) {
            dastomize_write_log_error('[dastomize_s3_upload_image_preview] Error: ' . $ex->getMessage());
            return null;
        }
    }
}

if ( !function_exists('dastomize_s3_remove_image_preview')) {
    function dastomize_s3_remove_image_preview($previewUrl)
    {
    }
}

if ( !function_exists('dastomize_s3_upload_json')) {
    function dastomize_s3_upload_json($storeId, $productId, $json)
    {
        try {
            $folder = 'final-design/json/';
            $newName = dastomize_s3_generate_random_string(20);

            $destinationFinalPath = dastomize_s3_destination_path($folder . $storeId . '/' . $productId);

            $fileName = $newName . '.json-' . time() . '.json';

            $apiToken = get_option('settings_page_api_token');
            $remoteUrl = DASTOMIZE_APP_API_S3_GET_UPLOAD;

            $client = new Client([
                'timeout'         => 300,
            ]);
            $res = $client->request('GET', $remoteUrl, [
                'headers' => [
                    'Authorization' => 'Bearer ' . $apiToken,
                    'x-amz-meta-filename'   => $fileName,
                    'x-amz-meta-filepath'   => $destinationFinalPath
                ]
            ]);
            $body = json_decode($res->getBody()->getContents());
            if (!empty($body->signed)) {
                $signedUrl = $body->signed;
                $url = $body->url;

                $res = $client->request('PUT', $signedUrl, [
                    'headers' => [
                        'Content-Type' => 'application/json',
                    ],
                    'body' => $json
                ]);
                return $destinationFinalPath . $fileName;
            }
        } catch (\Exception $ex) {
            dastomize_write_log_error('[dastomize_s3_upload_json] Error: ' . $ex->getMessage());
            return null;
        }
    }
}

if ( !function_exists('dastomize_s3_remove_json')) {
    function dastomize_s3_remove_json($jsonUrl)
    {
    }
}

if (! function_exists('dastomize_s3_destination_path')) {
    function dastomize_s3_destination_path($root = 'uploads/')
    {
        $dt = \Carbon\Carbon::now();
        $dest = "$root/{$dt->format('m/Y')}/";
        return $dest;
    }
}

if (! function_exists('dastomize_s3_generate_random_string')) {
    function dastomize_s3_generate_random_string($length = 10) {
        return substr(str_shuffle(str_repeat($x='0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ', ceil($length/strlen($x)) )),1,$length);
    }
}

if (! function_exists('dastomize_s3_get_original_url')) {
    function dastomize_s3_get_original_url() {
        return dastomize_env('S3_ORIGINAL_URL', 'https://s3.us-east-1.amazonaws.com/assets.dastomize.com/');
    }
}